Opinionated framework for building simulation apps with dynamecs.
Re-exports
Macros
- dynamecs_
main - Convenience macro for generating an appropriate main function for use with
dynamecs-app.
Structs
Functions
- get_
default_ output_ dir - Returns the default intended root directory for app output.
- get_
output_ dir - Returns the intended root directory for app output.
- register_
signal_ handler - Registers a signal handler that tries to ensure correct termination of logging in the presence of sudden program termination.
- setup_
tracing - Sets up
tracing.